Class: Google::Apis::VerifiedaccessV2::VerifyChallengeResponseRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/verifiedaccess_v2/classes.rb,
lib/google/apis/verifiedaccess_v2/representations.rb,
lib/google/apis/verifiedaccess_v2/representations.rb

Overview

Signed ChallengeResponse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerifyChallengeResponseRequest

Returns a new instance of VerifyChallengeResponseRequest.



383
384
385
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#challenge_responseString

Required. The generated response to the challenge, the bytes representation of SignedData. Corresponds to the JSON property challengeResponse NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


372
373
374
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 372

def challenge_response
  @challenge_response
end

#expected_identityString

Optional. Service can optionally provide identity information about the device or user associated with the key. For an EMK, this value is the enrolled domain. For an EUK, this value is the user's email address. If present, this value will be checked against contents of the response, and verification will fail if there is no match. Corresponds to the JSON property expectedIdentity

Returns:

  • (String)


381
382
383
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 381

def expected_identity
  @expected_identity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



388
389
390
391
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 388

def update!(**args)
  @challenge_response = args[:challenge_response] if args.key?(:challenge_response)
  @expected_identity = args[:expected_identity] if args.key?(:expected_identity)
end