Class: Google::Apis::VerifiedaccessV2::VerifyChallengeResponseResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/verifiedaccess_v2/classes.rb,
lib/google/apis/verifiedaccess_v2/representations.rb,
lib/google/apis/verifiedaccess_v2/representations.rb

Overview

Result message for VerifiedAccess.VerifyChallengeResponse. The response returned when successful for Managed profiles on Unmanaged browsers will NOT have devicePermanentId, keyTrustLevel, virtualDeviceId and customerId fields. Managed profiles will INSTEAD have the profileCustomerId, virtualProfileId, profilePermanentId and profileKeyTrustLevel fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerifyChallengeResponseResult

Returns a new instance of VerifyChallengeResponseResult.



478
479
480
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attested_device_idString

Output only. Attested device ID (ADID). Corresponds to the JSON property attestedDeviceId

Returns:

  • (String)


405
406
407
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 405

def attested_device_id
  @attested_device_id
end

#customer_idString

Output only. Unique customer id that this device belongs to, as defined by the Google Admin SDK at https://developers.google.com/admin-sdk/directory/v1/ guides/manage-customers Corresponds to the JSON property customerId

Returns:

  • (String)


412
413
414
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 412

def customer_id
  @customer_id
end

#device_enrollment_idString

Output only. Device enrollment id for ChromeOS devices. Corresponds to the JSON property deviceEnrollmentId

Returns:

  • (String)


417
418
419
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 417

def device_enrollment_id
  @device_enrollment_id
end

#device_permanent_idString

Output only. Device permanent id is returned in this field (for the machine response only). Corresponds to the JSON property devicePermanentId

Returns:

  • (String)


423
424
425
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 423

def device_permanent_id
  @device_permanent_id
end

#device_signalString

Output only. Deprecated. Device signal in json string representation. Prefer using device_signals instead. Corresponds to the JSON property deviceSignal

Returns:

  • (String)


429
430
431
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 429

def device_signal
  @device_signal
end

#device_signalsGoogle::Apis::VerifiedaccessV2::DeviceSignals

The device signals as reported by Chrome. Unless otherwise specified, signals are available on all platforms. Corresponds to the JSON property deviceSignals



435
436
437
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 435

def device_signals
  @device_signals
end

#key_trust_levelString

Output only. Device attested key trust level. Corresponds to the JSON property keyTrustLevel

Returns:

  • (String)


440
441
442
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 440

def key_trust_level
  @key_trust_level
end

#profile_customer_idString

Output only. Unique customer id that this profile belongs to, as defined by the Google Admin SDK at https://developers.google.com/admin-sdk/directory/v1/ guides/manage-customers Corresponds to the JSON property profileCustomerId

Returns:

  • (String)


447
448
449
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 447

def profile_customer_id
  @profile_customer_id
end

#profile_key_trust_levelString

Output only. Profile attested key trust level. Corresponds to the JSON property profileKeyTrustLevel

Returns:

  • (String)


452
453
454
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 452

def profile_key_trust_level
  @profile_key_trust_level
end

#profile_permanent_idString

Output only. The unique server-side ID of a profile on the device. Corresponds to the JSON property profilePermanentId

Returns:

  • (String)


457
458
459
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 457

def profile_permanent_id
  @profile_permanent_id
end

#signed_public_key_and_challengeString

Output only. Certificate Signing Request (in the SPKAC format, base64 encoded) is returned in this field. This field will be set only if device has included CSR in its challenge response. (the option to include CSR is now available for both user and machine responses) Corresponds to the JSON property signedPublicKeyAndChallenge

Returns:

  • (String)


465
466
467
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 465

def signed_public_key_and_challenge
  @signed_public_key_and_challenge
end

#virtual_device_idString

Output only. Virtual device id of the device. The definition of virtual device id is platform-specific. Corresponds to the JSON property virtualDeviceId

Returns:

  • (String)


471
472
473
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 471

def virtual_device_id
  @virtual_device_id
end

#virtual_profile_idString

Output only. The client-provided ID of a profile on the device. Corresponds to the JSON property virtualProfileId

Returns:

  • (String)


476
477
478
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 476

def virtual_profile_id
  @virtual_profile_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 483

def update!(**args)
  @attested_device_id = args[:attested_device_id] if args.key?(:attested_device_id)
  @customer_id = args[:customer_id] if args.key?(:customer_id)
  @device_enrollment_id = args[:device_enrollment_id] if args.key?(:device_enrollment_id)
  @device_permanent_id = args[:device_permanent_id] if args.key?(:device_permanent_id)
  @device_signal = args[:device_signal] if args.key?(:device_signal)
  @device_signals = args[:device_signals] if args.key?(:device_signals)
  @key_trust_level = args[:key_trust_level] if args.key?(:key_trust_level)
  @profile_customer_id = args[:profile_customer_id] if args.key?(:profile_customer_id)
  @profile_key_trust_level = args[:profile_key_trust_level] if args.key?(:profile_key_trust_level)
  @profile_permanent_id = args[:profile_permanent_id] if args.key?(:profile_permanent_id)
  @signed_public_key_and_challenge = args[:signed_public_key_and_challenge] if args.key?(:signed_public_key_and_challenge)
  @virtual_device_id = args[:virtual_device_id] if args.key?(:virtual_device_id)
  @virtual_profile_id = args[:virtual_profile_id] if args.key?(:virtual_profile_id)
end