Class: Google::Apis::VerifiedaccessV2::DeviceSignals
- Inherits:
-
Object
- Object
- Google::Apis::VerifiedaccessV2::DeviceSignals
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/verifiedaccess_v2/classes.rb,
lib/google/apis/verifiedaccess_v2/representations.rb,
lib/google/apis/verifiedaccess_v2/representations.rb
Overview
The device signals as reported by Chrome. Unless otherwise specified, signals are available on all platforms.
Instance Attribute Summary collapse
-
#allow_screen_lock ⇒ Boolean
(also: #allow_screen_lock?)
Output only.
-
#antivirus ⇒ Google::Apis::VerifiedaccessV2::Antivirus
Antivirus information on a device.
-
#browser_version ⇒ String
Output only.
-
#built_in_dns_client_enabled ⇒ Boolean
(also: #built_in_dns_client_enabled?)
Output only.
-
#chrome_remote_desktop_app_blocked ⇒ Boolean
(also: #chrome_remote_desktop_app_blocked?)
Output only.
-
#crowd_strike_agent ⇒ Google::Apis::VerifiedaccessV2::CrowdStrikeAgent
Properties of the CrowdStrike agent installed on a device.
-
#device_affiliation_ids ⇒ Array<String>
Output only.
-
#device_enrollment_domain ⇒ String
Output only.
-
#device_manufacturer ⇒ String
Output only.
-
#device_model ⇒ String
Output only.
-
#disk_encryption ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#hostname ⇒ String
Hostname of the device.
-
#imei ⇒ Array<String>
Output only.
-
#mac_addresses ⇒ Array<String>
Output only.
-
#meid ⇒ Array<String>
Output only.
-
#operating_system ⇒ String
Output only.
-
#os_firewall ⇒ String
Output only.
-
#os_version ⇒ String
Output only.
-
#password_protection_warning_trigger ⇒ String
Output only.
-
#profile_affiliation_ids ⇒ Array<String>
Output only.
-
#profile_enrollment_domain ⇒ String
Output only.
-
#realtime_url_check_mode ⇒ String
Output only.
-
#safe_browsing_protection_level ⇒ String
Output only.
-
#screen_lock_secured ⇒ String
Output only.
-
#secure_boot_mode ⇒ String
Output only.
-
#serial_number ⇒ String
Output only.
-
#site_isolation_enabled ⇒ Boolean
(also: #site_isolation_enabled?)
Output only.
-
#system_dns_servers ⇒ Array<String>
List of the addesses of all OS level DNS servers configured in the device's network settings.
-
#third_party_blocking_enabled ⇒ Boolean
(also: #third_party_blocking_enabled?)
Output only.
-
#trigger ⇒ String
Output only.
-
#windows_machine_domain ⇒ String
Output only.
-
#windows_user_domain ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceSignals
constructor
A new instance of DeviceSignals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceSignals
Returns a new instance of DeviceSignals.
305 306 307 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_screen_lock ⇒ Boolean Also known as: allow_screen_lock?
Output only. Value of the AllowScreenLock policy on the device. See https://
chromeenterprise.google/policies/?policy=AllowScreenLock for more details.
Available on ChromeOS only.
Corresponds to the JSON property allowScreenLock
100 101 102 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 100 def allow_screen_lock @allow_screen_lock end |
#antivirus ⇒ Google::Apis::VerifiedaccessV2::Antivirus
Antivirus information on a device.
Corresponds to the JSON property antivirus
106 107 108 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 106 def antivirus @antivirus end |
#browser_version ⇒ String
Output only. Current version of the Chrome browser which generated this set of
signals. Example value: "107.0.5286.0".
Corresponds to the JSON property browserVersion
112 113 114 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 112 def browser_version @browser_version end |
#built_in_dns_client_enabled ⇒ Boolean Also known as: built_in_dns_client_enabled?
Output only. Whether Chrome's built-in DNS client is used. The OS DNS client
is otherwise used. This value may be controlled by an enterprise policy: https:
//chromeenterprise.google/policies/#BuiltInDnsClientEnabled.
Corresponds to the JSON property builtInDnsClientEnabled
119 120 121 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 119 def built_in_dns_client_enabled @built_in_dns_client_enabled end |
#chrome_remote_desktop_app_blocked ⇒ Boolean Also known as: chrome_remote_desktop_app_blocked?
Output only. Whether access to the Chrome Remote Desktop application is
blocked via a policy.
Corresponds to the JSON property chromeRemoteDesktopAppBlocked
126 127 128 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 126 def chrome_remote_desktop_app_blocked @chrome_remote_desktop_app_blocked end |
#crowd_strike_agent ⇒ Google::Apis::VerifiedaccessV2::CrowdStrikeAgent
Properties of the CrowdStrike agent installed on a device.
Corresponds to the JSON property crowdStrikeAgent
132 133 134 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 132 def crowd_strike_agent @crowd_strike_agent end |
#device_affiliation_ids ⇒ Array<String>
Output only. Affiliation IDs of the organizations that are affiliated with the
organization that is currently managing the device. When the sets of device
and profile affiliation IDs overlap, it means that the organizations managing
the device and user are affiliated. To learn more about user affiliation,
visit https://support.google.com/chrome/a/answer/12801245?ref_topic=9027936.
Corresponds to the JSON property deviceAffiliationIds
141 142 143 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 141 def device_affiliation_ids @device_affiliation_ids end |
#device_enrollment_domain ⇒ String
Output only. Enrollment domain of the customer which is currently managing the
device.
Corresponds to the JSON property deviceEnrollmentDomain
147 148 149 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 147 def device_enrollment_domain @device_enrollment_domain end |
#device_manufacturer ⇒ String
Output only. The name of the device's manufacturer.
Corresponds to the JSON property deviceManufacturer
152 153 154 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 152 def device_manufacturer @device_manufacturer end |
#device_model ⇒ String
Output only. The name of the device's model.
Corresponds to the JSON property deviceModel
157 158 159 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 157 def device_model @device_model end |
#disk_encryption ⇒ String
Output only. The encryption state of the disk. On ChromeOS, the main disk is
always ENCRYPTED.
Corresponds to the JSON property diskEncryption
163 164 165 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 163 def disk_encryption @disk_encryption end |
#display_name ⇒ String
Output only. The display name of the device, as defined by the user.
Corresponds to the JSON property displayName
168 169 170 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 168 def display_name @display_name end |
#hostname ⇒ String
Hostname of the device.
Corresponds to the JSON property hostname
173 174 175 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 173 def hostname @hostname end |
#imei ⇒ Array<String>
Output only. International Mobile Equipment Identity (IMEI) of the device.
Available on ChromeOS only.
Corresponds to the JSON property imei
179 180 181 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 179 def imei @imei end |
#mac_addresses ⇒ Array<String>
Output only. MAC addresses of the device.
Corresponds to the JSON property macAddresses
184 185 186 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 184 def mac_addresses @mac_addresses end |
#meid ⇒ Array<String>
Output only. Mobile Equipment Identifier (MEID) of the device. Available on
ChromeOS only.
Corresponds to the JSON property meid
190 191 192 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 190 def meid @meid end |
#operating_system ⇒ String
Output only. The type of the Operating System currently running on the device.
Corresponds to the JSON property operatingSystem
195 196 197 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 195 def @operating_system end |
#os_firewall ⇒ String
Output only. The state of the OS level firewall. On ChromeOS, the value will
always be ENABLED on regular devices and UNKNOWN on devices in developer mode.
Support for MacOS 15 (Sequoia) and later has been introduced in Chrome M131.
Corresponds to the JSON property osFirewall
202 203 204 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 202 def os_firewall @os_firewall end |
#os_version ⇒ String
Output only. The current version of the Operating System. On Windows and linux,
the value will also include the security patch information.
Corresponds to the JSON property osVersion
208 209 210 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 208 def os_version @os_version end |
#password_protection_warning_trigger ⇒ String
Output only. Whether the Password Protection Warning feature is enabled or not.
Password protection alerts users when they reuse their protected password on
potentially suspicious sites. This setting is controlled by an enterprise
policy: https://chromeenterprise.google/policies/#
PasswordProtectionWarningTrigger. Note that the policy unset does not have the
same effects as having the policy explicitly set to PASSWORD_PROTECTION_OFF.
Corresponds to the JSON property passwordProtectionWarningTrigger
218 219 220 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 218 def password_protection_warning_trigger @password_protection_warning_trigger end |
#profile_affiliation_ids ⇒ Array<String>
Output only. Affiliation IDs of the organizations that are affiliated with the
organization that is currently managing the Chrome Profile’s user or ChromeOS
user.
Corresponds to the JSON property profileAffiliationIds
225 226 227 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 225 def profile_affiliation_ids @profile_affiliation_ids end |
#profile_enrollment_domain ⇒ String
Output only. Enrollment domain of the customer which is currently managing the
profile.
Corresponds to the JSON property profileEnrollmentDomain
231 232 233 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 231 def profile_enrollment_domain @profile_enrollment_domain end |
#realtime_url_check_mode ⇒ String
Output only. Whether Enterprise-grade (i.e. custom) unsafe URL scanning is
enabled or not. This setting may be controlled by an enterprise policy: https:/
/chromeenterprise.google/policies/#EnterpriseRealTimeUrlCheckMode
Corresponds to the JSON property realtimeUrlCheckMode
238 239 240 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 238 def realtime_url_check_mode @realtime_url_check_mode end |
#safe_browsing_protection_level ⇒ String
Output only. Safe Browsing Protection Level. That setting may be controlled by
an enterprise policy: https://chromeenterprise.google/policies/#
SafeBrowsingProtectionLevel.
Corresponds to the JSON property safeBrowsingProtectionLevel
245 246 247 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 245 def safe_browsing_protection_level @safe_browsing_protection_level end |
#screen_lock_secured ⇒ String
Output only. The state of the Screen Lock password protection. On ChromeOS,
this value will always be ENABLED as there is not way to disable requiring a
password or pin when unlocking the device.
Corresponds to the JSON property screenLockSecured
252 253 254 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 252 def screen_lock_secured @screen_lock_secured end |
#secure_boot_mode ⇒ String
Output only. Whether the device's startup software has its Secure Boot feature
enabled. Available on Windows only.
Corresponds to the JSON property secureBootMode
258 259 260 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 258 def secure_boot_mode @secure_boot_mode end |
#serial_number ⇒ String
Output only. The serial number of the device. On Windows, this represents the
BIOS's serial number. Not available on most Linux distributions.
Corresponds to the JSON property serialNumber
264 265 266 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 264 def serial_number @serial_number end |
#site_isolation_enabled ⇒ Boolean Also known as: site_isolation_enabled?
Output only. Whether the Site Isolation (a.k.a Site Per Process) setting is
enabled. That setting may be controlled by an enterprise policy: https://
chromeenterprise.google/policies/#SitePerProcess
Corresponds to the JSON property siteIsolationEnabled
271 272 273 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 271 def site_isolation_enabled @site_isolation_enabled end |
#system_dns_servers ⇒ Array<String>
List of the addesses of all OS level DNS servers configured in the device's
network settings.
Corresponds to the JSON property systemDnsServers
278 279 280 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 278 def system_dns_servers @system_dns_servers end |
#third_party_blocking_enabled ⇒ Boolean Also known as: third_party_blocking_enabled?
Output only. Deprecated. The corresponding policy is now deprecated. Whether
Chrome is blocking third-party software injection or not. This setting may be
controlled by an enterprise policy: https://chromeenterprise.google/policies/?
policy=ThirdPartyBlockingEnabled. Available on Windows only.
Corresponds to the JSON property thirdPartyBlockingEnabled
286 287 288 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 286 def third_party_blocking_enabled @third_party_blocking_enabled end |
#trigger ⇒ String
Output only. The trigger which generated this set of signals.
Corresponds to the JSON property trigger
292 293 294 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 292 def trigger @trigger end |
#windows_machine_domain ⇒ String
Output only. Windows domain that the current machine has joined. Available on
Windows only.
Corresponds to the JSON property windowsMachineDomain
298 299 300 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 298 def windows_machine_domain @windows_machine_domain end |
#windows_user_domain ⇒ String
Output only. Windows domain for the current OS user. Available on Windows only.
Corresponds to the JSON property windowsUserDomain
303 304 305 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 303 def windows_user_domain @windows_user_domain end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/google/apis/verifiedaccess_v2/classes.rb', line 310 def update!(**args) @allow_screen_lock = args[:allow_screen_lock] if args.key?(:allow_screen_lock) @antivirus = args[:antivirus] if args.key?(:antivirus) @browser_version = args[:browser_version] if args.key?(:browser_version) @built_in_dns_client_enabled = args[:built_in_dns_client_enabled] if args.key?(:built_in_dns_client_enabled) @chrome_remote_desktop_app_blocked = args[:chrome_remote_desktop_app_blocked] if args.key?(:chrome_remote_desktop_app_blocked) @crowd_strike_agent = args[:crowd_strike_agent] if args.key?(:crowd_strike_agent) @device_affiliation_ids = args[:device_affiliation_ids] if args.key?(:device_affiliation_ids) @device_enrollment_domain = args[:device_enrollment_domain] if args.key?(:device_enrollment_domain) @device_manufacturer = args[:device_manufacturer] if args.key?(:device_manufacturer) @device_model = args[:device_model] if args.key?(:device_model) @disk_encryption = args[:disk_encryption] if args.key?(:disk_encryption) @display_name = args[:display_name] if args.key?(:display_name) @hostname = args[:hostname] if args.key?(:hostname) @imei = args[:imei] if args.key?(:imei) @mac_addresses = args[:mac_addresses] if args.key?(:mac_addresses) @meid = args[:meid] if args.key?(:meid) @operating_system = args[:operating_system] if args.key?(:operating_system) @os_firewall = args[:os_firewall] if args.key?(:os_firewall) @os_version = args[:os_version] if args.key?(:os_version) @password_protection_warning_trigger = args[:password_protection_warning_trigger] if args.key?(:password_protection_warning_trigger) @profile_affiliation_ids = args[:profile_affiliation_ids] if args.key?(:profile_affiliation_ids) @profile_enrollment_domain = args[:profile_enrollment_domain] if args.key?(:profile_enrollment_domain) @realtime_url_check_mode = args[:realtime_url_check_mode] if args.key?(:realtime_url_check_mode) @safe_browsing_protection_level = args[:safe_browsing_protection_level] if args.key?(:safe_browsing_protection_level) @screen_lock_secured = args[:screen_lock_secured] if args.key?(:screen_lock_secured) @secure_boot_mode = args[:secure_boot_mode] if args.key?(:secure_boot_mode) @serial_number = args[:serial_number] if args.key?(:serial_number) @site_isolation_enabled = args[:site_isolation_enabled] if args.key?(:site_isolation_enabled) @system_dns_servers = args[:system_dns_servers] if args.key?(:system_dns_servers) @third_party_blocking_enabled = args[:third_party_blocking_enabled] if args.key?(:third_party_blocking_enabled) @trigger = args[:trigger] if args.key?(:trigger) @windows_machine_domain = args[:windows_machine_domain] if args.key?(:windows_machine_domain) @windows_user_domain = args[:windows_user_domain] if args.key?(:windows_user_domain) end |